% This example demonstrates how to perform the EMD as a time-domain
% filter.  It is a script, not a function, so you must edit it if
% you desire to change the way it behaves.  There are two methods of
% loading data in this file- one for matlab data, and the other for
% ASCII data.  To use your own ASCII data, you will need an ASCII
% spreadsheet.  The first column contains the times for each sample.
% The remaining columns contain the data, one column per signal. Your file
% can contain a header row only if it begins with a '%'
%
% Note: the current settings for the EMD in this will take a very long
%  time to complete.  You have been warned.
%
%   Bradley M. Battista
%   University of South Carolina
%   Department of Geological Sciences
%   701 Sumter Street, EWS 617
%   Columbia, SC. 29208
%
% COPYRIGHT: see the associated COPYRIGHT.txt file, and also
% http://software.seg.org/disclaimer2.txt
% This source code may be found online at:
% http://software.seg.org/2007/0003
%

% load data
load line15.mat

% or to load ASCII data having sample times in column 1
% and data in every following column, delimited by tabs or spaces
load line15.txt
t = line15(:,1);
x = line15(:,2:end);
clear line15

% perform EMD on all columns of data, producing
% no more than 10 IMFS and sifting no more than
% 1000 times for each IMF.
[imf,cumIMF] = mat_emd(x,10,1000);

% interactively select output traces
[y,index] = IMFpick(x,t,cumIMF,[]);


